@@ -1,7 +1,7 @@
 <?php
 /*
   This code is part of FusionDirectory (http://www.fusiondirectory.org/)
-  Copyright (C) 2013  FusionDirectory
+  Copyright (C) 2013-2018  FusionDirectory
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -72,7 +72,7 @@ function initiateRPCSession($id = NULL, $ldap = NULL, $user = NULL, $pwd = NULL)
     $config = session::global_get('config');
     $plist  = session::global_get('plist');
     $ui     = session::global_get('ui');
-    initLanguage();
+    Language::init();
   } else {
     $config = new config(CONFIG_DIR."/".CONFIG_FILE, $BASE_DIR);
     if ($ldap === NULL) {
@@ -202,6 +202,7 @@ class fdRPCService
    */
   protected function _ls ($type, $attrs = NULL, $ou = NULL, $filter = '')
   {
+    global $config, $ui;
     $this->checkAccess($type);
     return objects::ls($type, $attrs, $ou, $filter, TRUE);
   }
@@ -215,8 +216,8 @@ class fdRPCService
     $this->checkAccess($type);
     $infos  = objects::infos($type);
     $acl    = $infos['aclCategory'].'/'.$infos['mainTab'];
-    if (strpos($ui->get_permissions($ou, $acl), 'r') !== FALSE) {
-      return objects::count($type, $ou, $filter);
+    if ((strpos($ui->get_permissions($ou, $acl), 'r') !== FALSE) && ($filter == '')) {
+      return objects::count($type, $ou, $filter, TRUE);
     } else {
       return count(objects::ls($type, NULL, $ou, $filter, TRUE));
     }
@@ -475,6 +476,77 @@ class fdRPCService
     return $tabobject->dn;
   }
 
+  /*!
+   * \brief Add values to an object's attributes and save it
+   */
+  protected function _addvalues($type, $dn, $values)
+  {
+    return $this->adddelvalues($type, $dn, $values, TRUE);
+  }
+
+  /*!
+   * \brief Delete values from an object's attributes and save it
+   */
+  protected function _delvalues($type, $dn, $values)
+  {
+    return $this->adddelvalues($type, $dn, $values, FALSE);
+  }
+
+  private function adddelvalues($type, $dn, $values, $add)
+  {
+    $this->checkAccess($type, array_keys($values), $dn);
+    if ($dn === NULL) {
+      return array('errors' => array('No DN provided'));
+    } else {
+      $tabobject = objects::open($dn, $type);
+    }
+    foreach ($values as $tab => $tabvalues) {
+      if (!isset($tabobject->by_object[$tab])) {
+        return array('errors' => array('This tab does not exists: "'.$tab.'"'));
+      }
+      if (is_subclass_of($tabobject->by_object[$tab], 'simplePlugin') &&
+          $tabobject->by_object[$tab]->displayHeader &&
+          !$tabobject->by_object[$tab]->is_account
+        ) {
+        if ($tabobject->by_object[$tab]->acl_is_createable()) {
+          $tabobject->by_object[$tab]->is_account = TRUE;
+        } else {
+          return array('errors' => array('You don\'t have sufficient rights to enable tab "'.$tab.'"'));
+        }
+      }
+      foreach ($tabvalues as $name => $newvalues) {
+        if (isset($tabobject->by_object[$tab]->attributesAccess[$name])) {
+          if ($tabobject->by_object[$tab]->attrIsWriteable($name)) {
+            $attrvalues = $tabobject->by_object[$tab]->attributesAccess[$name]->getValue();
+            if (!is_array($attrvalues)) {
+              return array('errors' => array(sprintf(_('Field "%s" is not multi-valuated'), $name)));
+            }
+            if (!is_array($newvalues)) {
+              $newvalues = array($newvalues);
+            }
+            if ($add) {
+              $attrvalues = array_merge($attrvalues, $newvalues);
+            } else {
+              $attrvalues = array_remove_entries($newvalues, $attrvalues);
+            }
+            $tabobject->by_object[$tab]->attributesAccess[$name]->setValue($attrvalues);
+          } else {
+            return array('errors' => array(msgPool::permModify($dn, $name)));
+          }
+        } else {
+          return array('errors' => array(sprintf(_('Unknown field "%s"'), $name)));
+        }
+      }
+      $tabobject->current = $tab;
+      $tabobject->save_object(); /* Should not do much as POST is empty, but in some cases is needed */
+    }
+    $errors = $tabobject->save();
+    if (!empty($errors)) {
+      return array('errors' => $errors);
+    }
+    return $tabobject->dn;
+  }
+
   /*!
    * \brief Get all internal fields from a template
    */
@@ -542,7 +614,7 @@ class fdRPCService
     // Filter out entries we are not allowed to modify
     $disallowed = array();
 
-    if(!is_array($dns)) {
+    if (!is_array($dns)) {
       $dns = array($dns);
     }
 
@@ -611,7 +683,7 @@ class fdRPCService
   {
     global $config, $ui;
 
-    if(!is_array($dns)) {
+    if (!is_array($dns)) {
       $dns = array($dns);
     }
 
